Exception: FinalClassMethodEmptyDefinitionError

Inherits:
FinalMethodError show all
Defined in:
lib/final_method/final_method_exceptions.rb

Overview

Raised when final class method is declared but not defined in parent class and is attempted to be defined in child class